<?php


namespace Drupal\icons;


use Drupal\Core\Entity\EntityTypeManagerInterface;

class IconsManager {

  /**
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * IconsManager constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * @return array
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function getIconOptions(): array {
    $options = [];

    $iconSetStorage = $this->entityTypeManager->getStorage('icon_set');

    /** @var \Drupal\icons\Entity\IconSetInterface[] $icon_sets */
    $icon_sets = $iconSetStorage->loadMultiple();

    $use_groups = FALSE;
    if (count($icon_sets) > 1) {
      $use_groups = TRUE;
    }

    // Add a library whose information changes depending on certain conditions.
    foreach ($icon_sets as $icon_set) {
      /** @var \Drupal\icons_icomoon\Plugin\IconLibrary\IcoMoon $plugin */
      $plugin = $icon_set->getPlugin();
      $icons = $plugin->getIcons();

      $icon_values = [];
      foreach ($icons as $icon_key => $icon_title) {
        $icon_values[$icon_set->id() . ':' . $icon_key] = $icon_title;
      }

      if ($use_groups) {
        $options[$icon_set->label()] = $icon_values;
      }
      else {
        $options = $icon_values;
      }
    }

    return $options;
  }
}
